# Pull Request

## Summary

<!-- Provide a clear and concise description of what this PR does -->

## Breaking Changes

- [ ] This PR introduces breaking changes

<!-- If yes, describe what breaks and migration steps -->

## Changelog Entry

- [ ] Added changelog fragment in `changelog.d/` directory
- [ ] No changelog entry needed (non-changelog category)

## Testing & Quality

- [ ] All tests pass locally (`nox -s tests`)
- [ ] Linting and Type checking passes (`nox -s check`)
- [ ] Added tests for new functionality
- [ ] Updated documentation if needed
- [ ] Tested manually (if applicable)

## Review Checklist

- [ ] Code follows project style guidelines
- [ ] Self-review completed
- [ ] Added appropriate labels
- [ ] Linked related issues (closes #123)
- [ ] PR title follows conventional commits format
- [ ] All CI checks are passing

## Additional Context

<!-- Any additional information, screenshots, or context about the PR -->
